==> webkit2gtk_2.32.4.orig.tar.xz: webkitgtk-2.32.4/Source/WebDriver/socket/CapabilitiesSocket.cpp <==
/*
 * Copyright (C) 2020 Sony Interactive Entertainment Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "CapabilitiesSocket.h"

namespace WebDriver {

void CapabilitiesSocket::parseCapabilities(const JSON::Object& matchedCapabilities, Capabilities& capabilities)
{
    RefPtr<JSON::Value> targetAddrValue;
    String targetAddr;
    if (matchedCapabilities.getValue("socket:targetAddr", targetAddrValue) && targetAddrValue->asString(targetAddr))
        capabilities.targetAddr = targetAddr;

    RefPtr<JSON::Value> targetPortValue;
    int targetPort;
    if (matchedCapabilities.getValue("socket:targetPort", targetPortValue) && targetPortValue->asInteger(targetPort))
        capabilities.targetPort = targetPort;
}

} // namespace WebDriver

==> webkit2gtk_2.50.5.orig.tar.xz: webkitgtk-2.50.5/Source/WebDriver/socket/CapabilitiesSocket.cpp <==
/*
 * Copyright (C) 2020 Sony Interactive Entertainment Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "CapabilitiesSocket.h"

namespace WebDriver {

void CapabilitiesSocket::parseCapabilities(const JSON::Object& matchedCapabilities, Capabilities& capabilities)
{
    RefPtr<JSON::Value> targetAddrValue;
    String targetAddr;
    if (matchedCapabilities.getValue("socket:targetAddr"_s, targetAddrValue) && targetAddrValue->asString(targetAddr))
        capabilities.targetAddr = targetAddr;

    RefPtr<JSON::Value> targetPortValue;
    int targetPort;
    if (matchedCapabilities.getValue("socket:targetPort"_s, targetPortValue) && targetPortValue->asInteger(targetPort))
        capabilities.targetPort = targetPort;
}

} // namespace WebDriver
